@@ -622,8 +622,8 @@ class BiCoN(object):
         genes1, genes2 = solution[0]
         patients1, patients2 = solution[1]
 
-        means1 = list(np.mean(GE[patients1].loc[genes1], axis=1) - np.mean(GE[patients2].loc[genes1], axis=1).values)
-        means2 = list(np.mean(GE[patients1].loc[genes2], axis=1) - np.mean(GE[patients2].loc[genes2], axis=1).values)
+        means1 = list(np.mean(GE[patients1].reindex(index = genes1), axis=1) - np.mean(GE[patients2].reindex(index = genes1), axis=1).values)
+        means2 = list(np.mean(GE[patients1].reindex(index = genes2), axis=1) - np.mean(GE[patients2].reindex(index = genes2), axis=1).values)
 
         G_small = nx.subgraph(G, genes1 + genes2)
 
@@ -833,8 +833,8 @@ class BiCoN(object):
         return results
 
     def new_score(self, GE, pg, npg, gg):
-        dif = np.mean(np.mean(GE[pg].loc[gg], axis=1)) - np.mean(np.mean(
-            GE[npg].loc[gg], axis=1))
+        dif = np.mean(np.mean(GE[pg].reindex(index = gg), axis=1)) - np.mean(np.mean(
+            GE[npg].reindex(index = gg), axis=1))
         return dif
 
     def do_action_nodes(self, action, nodes):
